#Metadata----

#Author: Timothy Swartz
#Contact: timothy.swartz@temple.edu
#Date: 30 June, 2019


# Description:
  #Code used for analysis and visualization of data associated with the following manuscript: 
  #Manuscript Title: "Identifying Opportunities to Conserve Farm Ponds on Private Lands: Integration of Social, Ecological, and Historical Data"
  #Manuscript Authors: Timothy Swartz, Jaime Coon, Jenna Mattes, and James Miller
  #Submitted to: Land, 30 June, 2019
  
  #See manuscript Tables 1 & 2 for descriptions of dependent and response variables


#Load libraries----
library(AICcmodavg)
library(ggplot2)
library(ggpubr)
#library(dplyr)
library(gridExtra)
library(multcomp)
library(sjstats)
library(lsr)
library(lme4)
library(tweedie)
library(statmod)
library(tidyverse)
library(cowplot)

#Load Data----
setwd()
ponds.w.laow1 <- read.csv("Data S1_Pond habitat and landowner response data.csv")

#_Centering and Scaling----
#scale independent variables to have mean of 0 and standard deviation of 1
ponds.w.laow <- ponds.w.laow1 %>% mutate_at(c("q29Gender","q31IncomeTot","q34Education","Age","PondsOwned","q8dIMPIncomeAgr","q8fIMPLivestock","q8gIMPPropVal","q8hIMPEnjoy","q8iIMPRec","q8jIMPCrops","q9aIMPSoil","q9bIMPBiodiversity","q9cIMPWildlifeHabitat","q12mIMPDucks","q12nIMPBullfrogs","q12oIMPOtherFrogs","q12pIMPSportFish","q32ProportionIncomeLand","q2aAcresOwned","q2bAcresRented","q3LiveonLand","q12m2ManageDucks","q12n2ManageBullfrogs","q12o2ManageOtherFrogs","q12p2ManageSportFish")
                                            ,funs(scale(.) %>% as.vector))

#1. Descriptive Statistics----
#_1. Pond Size----
ponds.w.laow1 <-  ponds.w.laow1 %>% 
  mutate(LCovAreaAcres = (LCovAreaM2*0.000247105)) #convert meters^2 to acres
  
summary(ponds.w.laow1$LCovAreaAcres) #obtain summary stats for pond size
#   Min.  1st Qu.   Median     Mean  3rd Qu.     Max. 
#0.01679  0.21230  0.42815  0.71360  0.76162 11.05180 

sd(ponds.w.laow1$LCovAreaAcres)
#_1a. Pond Age----
ponds.w.laow2 <- ponds.w.laow %>%
  filter(!AgeCategory == "")

pondage.plot <- ggplot(ponds.w.laow2,aes(x = AgeCategory))+
  geom_bar(aes(AgeCategory,y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Pond Age (years)",title = "(a)")+
  scale_x_discrete(labels=c("<10" = "<10","10-19" = "10-19","20-29" = "20-29", "30-39"="30-39","40-49"= "40-49","50-59" = "50-59","60+" = "60+"))+
  theme(axis.text.x=element_text(angle=-55, hjust=0))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = AgeCategory,label = ..count.., y= ..prop..), stat= "count")

#_1b. Cattails----
ponds.w.laow.cattails <- ponds.w.laow
ponds.w.laow.cattails$Cattails <- as.factor(ponds.w.laow.cattails$Cattails)

cattails.plot <- ggplot(ponds.w.laow.cattails,aes(x =Cattails))+
  geom_bar(aes(x = Cattails, y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Cattail Cover",title = "(b)")+ 
  scale_x_discrete(labels=c("0"="0%","1"="0-5 %","2"="5-25%","3"="25-50%","4"="50-75%","5"="75-100%"))+
  theme(axis.text.x=element_text(angle=-55, hjust=0))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = Cattails,label = ..count.., y= ..prop..), stat= "count")

#_1c. floating veg----
ponds.w.laow.floating <- ponds.w.laow
ponds.w.laow.floating$Floating <- as.factor(ponds.w.laow.floating$Floating)

floating.plot <- ggplot(ponds.w.laow.floating, aes(x =Floating))+
  geom_bar(aes(x = Floating, y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Floating Vegetation Cover",title = "(c)")+ 
  scale_x_discrete(labels=c("0"="0%","1"="0-5 %","2"="5-25%","3"="25-50%","4"="50-75%","5"="75-100%"))+
  theme(axis.text.x=element_text(angle=-55, hjust=0))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = Floating,label = ..count.., y= ..prop..), stat= "count")

#_1d. total veg----
ponds.w.laow.totalveg <- ponds.w.laow
ponds.w.laow.totalveg$TotalVeg <- as.factor(ponds.w.laow.totalveg$TotalVeg)

ponds.w.laow.totalveg1 <- ponds.w.laow.totalveg %>%
  filter(!ponds.w.laow.totalveg$TotalVeg == "0")

summary(ponds.w.laow.totalveg$TotalVeg)
#  veg.category: 0   1   2   3   4   5 
#  count:        0 354 163  60  37  41 

totalveg.plot <- ggplot(ponds.w.laow.totalveg,aes(x =TotalVeg))+
  geom_bar(aes(x = TotalVeg, y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Total Vegetation Cover",title = "(d)")+ 
  scale_x_discrete(labels=c("0"="0%","1"="0-5 %","2"="5-25%","3"="25-50%","4"="50-75%","5"="75-100%"))+
  theme(axis.text.x=element_text(angle=-55, hjust=0))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = TotalVeg,label = ..count.., y= ..prop..), stat= "count")

#_1e. Renovation status----
ponds.w.laow.40 <- ponds.w.laow %>%
  filter(PondOriginYR <= 1990)
ponds.w.laow.40$RebuiltYN <- as.factor(ponds.w.laow.40$RebuiltYN)

renovated.plot <- ggplot(ponds.w.laow.40,aes(x = RebuiltYN))+
  geom_bar(aes(RebuiltYN,y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Renovation",title = "(e)")+
  scale_x_discrete(labels=c("0" = "Not Rebuilt", "1" = "Rebuilt"))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = RebuiltYN,label = ..count.., y= ..prop..), stat= "count")

#_1f. permanence----
ponds.w.laow.perm <- ponds.w.laow
ponds.w.laow.perm$Permanent <- as.factor(ponds.w.laow.perm$Permanent)

perm.plot <- ggplot(ponds.w.laow.perm)+
  geom_bar(aes(Permanent,y = ..prop.., group = 1))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Permanence",title = "(f)")+ 
  scale_x_discrete(labels=c("0"="Not Permanent","1" ="Permanent"))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = Permanent,label = ..count.., y= ..prop..), stat= "count")

#_1g. Fencing ----
ponds.w.laow$Fence <- as.factor(ponds.w.laow$Fence)

fence.plot <- ggplot(ponds.w.laow,aes(x = Fence))+
  geom_bar(aes(Fence,y = (..count../899),group = Fence))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Fence",title = "(g)")+
  scale_x_discrete(labels=c("0" = "Absent", "1" = "Present", "2" = "Partial"))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = Fence, label = ..count.., y= ..prop..), stat= "count")

#_1h. Cattle access on grazed ponds----
ponds.w.laowGRAZED1 <- ponds.w.laow %>%
  filter(GrazedLand ==1)

ponds.w.laowGRAZED1$CattleIN <- as.factor(ponds.w.laowGRAZED1$CattleIN)
ponds.w.laowGRAZED1$Fence <- as.factor(ponds.w.laowGRAZED1$Fence)

summary(ponds.w.laowGRAZED1$CattleIN)
summary(ponds.w.laowGRAZED1$Fence)

cattleaccess.plot <- ggplot(ponds.w.laowGRAZED1,aes(x = CattleIN))+
  geom_bar(aes(CattleIN, y = ..count../421))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Cattle (grazed)",title = "(h)")+
  theme(legend.position = "top")+
  scale_x_discrete(labels=c("0" = "Absent", "1" = "Present"))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = CattleIN,label = ..count.., y= ..prop..), stat= "count")

#_1i. Fenced grazed----
ponds.w.laowGRAZED2 <- ponds.w.laow %>%
  filter(GrazedLand ==1) %>%
  filter(Fence == 1)

ponds.w.laowGRAZED2$CattleIN <- as.factor(ponds.w.laowGRAZED2$CattleIN)
ponds.w.laowGRAZED2$Fence <- as.factor(ponds.w.laowGRAZED2$Fence)

fence.grazed.plot <- ggplot(ponds.w.laowGRAZED2,aes(x = CattleIN))+
  geom_bar(aes(CattleIN,y = (..count../421),group = CattleIN))+  
  theme_pubr()+
  labs(y = "Proportion of Ponds", x = "Cattle (grazed & fenced)",title = "(i)")+
  scale_x_discrete(labels=c("0" = "Absent", "1" = "Present", "2" = "Partial"))+
  scale_y_continuous(limits = c(0, 1))+
  geom_text(aes(x = CattleIN, label = ..count.., y= ..prop..), stat= "count")



#Figure 3.----
plot_grid(pondage.plot,
          cattails.plot,
          floating.plot,
          totalveg.plot,
          renovated.plot,
          perm.plot,
          fence.plot,
          cattleaccess.plot,
          fence.grazed.plot, 
          align = "v", nrow = 3, ncol = 3, axis = "none")

#2. Regression Functions----
#create functions to be used in the GLMM process
AICregress_mods <- function(y,df) {
  #Null
  Null=lmer(y~1+(1|LaOw_ID),na.action = na.exclude,data=df,REML="FALSE") 
  
  #__Demographics________________________________________________________________________________________________________
  q29Gender                      =lmer(y~q29Gender+(1|LaOw_ID),data=df,REML="FALSE")
  q31IncomeTot                   =lmer(y~q31IncomeTot+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q34Education                   =lmer(y~q34Education+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  Age                            =lmer(y~Age+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  NumbPonds                      =lmer(y~PondsOwned+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  #__Values________________________________________________________________________________________________________
  #Q1.AquaticWildlifeMeanScorenoDK   =lmer(AvgAge~AquaticWildlifeMeanScorenoDK+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.l,REML="FALSE")
  q8dIMPIncomeAg                 =lmer(y~q8dIMPIncomeAgr+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q8fIMPLivestoc                 =lmer(y~q8fIMPLivestock+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q8gIMPPropVa                   =lmer(y~q8gIMPPropVal+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q8hIMPEnjoy                    =lmer(y~q8hIMPEnjoy+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q8iIMPRec                      =lmer(y~q8iIMPRec+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q8jIMPCrops                    =lmer(y~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q9aIMPSoil                     =lmer(y~q9aIMPSoil+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q9bIMPBiodiversity             =lmer(y~q9bIMPBiodiversity+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q9cIMPWildlifeHabitat          =lmer(y~q9cIMPWildlifeHabitat+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12mIMPDucks                   =lmer(y~q12mIMPDucks+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12nIMPBullfrogs               =lmer(y~q12nIMPBullfrogs+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12oIMPOtherFrogs              =lmer(y~q12oIMPOtherFrogs+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12pIMPSportFish               =lmer(y~q12pIMPSportFish+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  #__IncomeandAcres________________________________________________________________________________________________________
  q32ProportionIncomeLand        =lmer(y~q32ProportionIncomeLand+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q2aAcresOwned                  =lmer(y~q2aAcresOwned+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q2bAcresRented                 =lmer(y~q2bAcresRented+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q3LiveonLand                   =lmer(y~q3LiveonLand+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  #__Management________________________________________________________________________________________________________
  q12m2ManageDucks               =lmer(y~q12m2ManageDucks+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12n2ManageBullfrogs           =lmer(y~q12n2ManageBullfrogs+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12o2ManageOtherFrogs          =lmer(y~q12o2ManageOtherFrogs+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  q12p2ManageSportFish           =lmer(y~q12p2ManageSportFish+(1|LaOw_ID),na.action=na.exclude,data=df,REML="FALSE")
  
  mods=list(Null,q29Gender,q31IncomeTot,q34Education,Age,NumbPonds,q8dIMPIncomeAg,q8fIMPLivestoc,q8gIMPPropVa,q8hIMPEnjoy,q8iIMPRec,q8jIMPCrops,q9aIMPSoil,q9bIMPBiodiversity,q9cIMPWildlifeHabitat,q12mIMPDucks,q12nIMPBullfrogs,q12oIMPOtherFrogs,q12pIMPSportFish,q32ProportionIncomeLand,q2aAcresOwned,q2bAcresRented,q3LiveonLand,q12m2ManageDucks,q12n2ManageBullfrogs,q12o2ManageOtherFrogs,q12p2ManageSportFish)
  names=c("Null","Gender","IncomeTotal","Education","Age","Ponds Owned","IncomeAg","Livestock","PropertyValue","EnjoyingLand","Recreation","Crops","Soil","Biodiversity","WildlifeHabitat","Ducks","Bullfrogs","OtherFrogs","SportFish","PropIncomeLand","LogAcresOwned","LogAcresRented","LiveonLand","ManageDucks","ManageBullfrogs","ManageOtherFrogs","ManageSportFish")
  print(aictab(cand.set = mods, modnames = names,second.ord = FALSE), digits = 4)
  } #general linear mixed model function
AICregress_modsBIN <- function(y,df,f) { #y = response, df = data frame or tibble, f = family of distributions (e.g., binomial, gaussian, poisson)
  #Null
  Null=glmer(y~1+(1|LaOw_ID),family = f,na.action = na.exclude,data=df,REML="FALSE") 
  
  #__Demographics________________________________________________________________________________________________________
  q29Gender                      =glmer(y~q29Gender+(1|LaOw_ID),family = f, data=df,REML="FALSE")
  q31IncomeTot                   =glmer(y~q31IncomeTot+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q34Education                   =glmer(y~q34Education+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  Age                            =glmer(y~Age+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  NumbPonds                      =glmer(y~PondsOwned+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  #__Values________________________________________________________________________________________________________
  q8dIMPIncomeAg                 =glmer(y~q8dIMPIncomeAgr+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q8fIMPLivestoc                 =glmer(y~q8fIMPLivestock+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q8gIMPPropVa                   =glmer(y~q8gIMPPropVal+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q8hIMPEnjoy                    =glmer(y~q8hIMPEnjoy+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q8iIMPRec                      =glmer(y~q8iIMPRec+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q8jIMPCrops                    =glmer(y~q8jIMPCrops+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q9aIMPSoil                     =glmer(y~q9aIMPSoil+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q9bIMPBiodiversity             =glmer(y~q9bIMPBiodiversity+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q9cIMPWildlifeHabitat          =glmer(y~q9cIMPWildlifeHabitat+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12mIMPDucks                   =glmer(y~q12mIMPDucks+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12nIMPBullfrogs               =glmer(y~q12nIMPBullfrogs+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12oIMPOtherFrogs              =glmer(y~q12oIMPOtherFrogs+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12pIMPSportFish               =glmer(y~q12pIMPSportFish+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  #__IncomeandAcres________________________________________________________________________________________________________
  q32ProportionIncomeLand        =glmer(y~q32ProportionIncomeLand+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q2aAcresOwned                  =glmer(y~q2aAcresOwned+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q2bAcresRented                 =glmer(y~q2bAcresRented+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q3LiveonLand                   =glmer(y~q3LiveonLand+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  #__Management________________________________________________________________________________________________________
  q12m2ManageDucks               =glmer(y~q12m2ManageDucks+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12n2ManageBullfrogs           =glmer(y~q12n2ManageBullfrogs+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12o2ManageOtherFrogs          =glmer(y~q12o2ManageOtherFrogs+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  q12p2ManageSportFish           =glmer(y~q12p2ManageSportFish+(1|LaOw_ID),family = f,na.action=na.exclude,data=df,REML="FALSE")
  
  mods=list(Null,q29Gender,q31IncomeTot,q34Education,Age,NumbPonds,q8dIMPIncomeAg,q8fIMPLivestoc,q8gIMPPropVa,q8hIMPEnjoy,q8iIMPRec,q8jIMPCrops,q9aIMPSoil,q9bIMPBiodiversity,q9cIMPWildlifeHabitat,q12mIMPDucks,q12nIMPBullfrogs,q12oIMPOtherFrogs,q12pIMPSportFish,q32ProportionIncomeLand,q2aAcresOwned,q2bAcresRented,q3LiveonLand,q12m2ManageDucks,q12n2ManageBullfrogs,q12o2ManageOtherFrogs,q12p2ManageSportFish)
  names=c("Null","Gender","IncomeTotal","Education","Age","Ponds Owned","IncomeAg","Livestock","PropertyValue","EnjoyingLand","Recreation","Crops","Soil","Biodiversity","WildlifeHabitat","Ducks","Bullfrogs","OtherFrogs","SportFish","PropIncomeLand","LogAcresOwned","LogAcresRented","LiveonLand","ManageDucks","ManageBullfrogs","ManageOtherFrogs","ManageSportFish")
  print(aictab(cand.set = mods, modnames = names,second.ord = FALSE), digits = 4)
  
}


#_2a. PondAge----
AICregress_mods(ponds.w.laow$AvgAge,ponds.w.laow)
#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#IncomeAg         4 2724.358    0.0000 0.0862 0.0862 -1358.179
#Crops            4 2724.874    0.5162 0.0666 0.1527 -1358.437
#Null             3 2724.934    0.5758 0.0646 0.2173 -1359.467

q8dIMPIncomeAg.mod = lmer(AvgAge~q8dIMPIncomeAgr+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8dIMPIncomeAg.mod)
#Fixed effects:
#  Estimate Std. Error t value
#(Intercept)       35.454      1.190  29.790
#q8dIMPIncomeAgr   -2.324      1.445  -1.608
confint(q8dIMPIncomeAg.mod,level=0.85)
#q8dIMPIncomeAgr -4.406815 -0.2403156

q8jIMPCrops.mod = lmer(AvgAge~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8jIMPCrops.mod)
#            Estimate Std. Error t value
#(Intercept)   35.555      1.212  29.339
#q8jIMPCrops   -1.766      1.228  -1.438
confint(q8jIMPCrops.mod,level=0.85)
#q8jIMPCrops -3.536522  0.005427711



#_2b. Cattails----
AICregress_mods(ponds.w.laow$Cattails,ponds.w.laow)
#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#Crops            4 3317.192    0.0000 0.7663 0.7663 -1654.596
#Age              4 3322.739    5.5465 0.0479 0.8142 -1657.369
#IncomeAg         4 3323.184    5.9922 0.0383 0.8525 -1657.592
#IncomeTotal      4 3324.140    6.9482 0.0237 0.8762 -1658.070
#LogAcresRented   4 3325.247    8.0544 0.0137 0.8899 -1658.623
#WildlifeHabitat  4 3325.810    8.6181 0.0103 0.9002 -1658.905
#Livestock        4 3326.200    9.0084 0.0085 0.9087 -1659.100
#Null             3 3326.311    9.1189 0.0080 0.9167 -1660.156

#q8jIMPCrops
q8jIMPCrops.mod=lmer(Cattails~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8jIMPCrops.mod)
#             Estimate Std. Error t value 
#(Intercept)  0.81125    0.06391  12.693 
#q8jIMPCrops -0.21702    0.06172  -3.516.
confint(q8jIMPCrops.mod,level=0.85)
#q8jIMPCrops -0.3060603 -0.1267881


#Age
Age.mod=lmer(Cattails~Age+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(Age.mod)
#            Estimate Std. Error t value
#(Intercept)  0.83099    0.06803  12.214
#Age          0.15258    0.06407   2.381
confint(Age.mod,level=0.85)
#Age          0.06013559 0.2456150

#q8dIMPIncomeAgr
q8dIMPIncomeAgr.mod=lmer(Cattails~q8dIMPIncomeAgr+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8dIMPIncomeAgr.mod)
#                Estimate Std. Error t value
#(Intercept)      0.81285    0.06794  11.965
#q8dIMPIncomeAgr -0.13956    0.06076  -2.297
confint(q8dIMPIncomeAgr.mod,level=0.85)
#q8dIMPIncomeAgr -0.2271670 -0.05145725

#q31IncomeTot
q31IncomeTot.mod=lmer(Cattails~q31IncomeTot+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q31IncomeTot.mod)
#             Estimate Std. Error t value
#(Intercept)   0.82311    0.06834  12.044
#q31IncomeTot -0.13594    0.06603  -2.059
confint(q31IncomeTot.mod,level = 0.85)
#q31IncomeTot -0.2318867 -0.04058086

#q2bAcresRented
q2bAcresRented.mod=lmer(Cattails~q2bAcresRented+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q2bAcresRented.mod)
#               Estimate Std. Error t value
#(Intercept)     0.80994    0.06962  11.633
#q2bAcresRented -0.12983    0.07383  -1.759
confint(q2bAcresRented.mod,level = 0.85)
#q2bAcresRented -0.2379598 -0.02331097

#q9cIMPWildlifeHabitat
q9cIMPWildlifeHabitat.mod=lmer(Cattails~q9cIMPWildlifeHabitat+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q9cIMPWildlifeHabitat.mod)
#                      Estimate Std. Error t value
#(Intercept)            0.81956    0.06849  11.966
#q9cIMPWildlifeHabitat  0.10310    0.06430   1.603
confint(q9cIMPWildlifeHabitat.mod,level = 0.85)
#q9cIMPWildlifeHabitat 0.009404912 0.1958228

#q8fIMPLivestock
q8fIMPLivestock.mod=lmer(Cattails~q8fIMPLivestock+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8fIMPLivestock.mod)
#                Estimate Std. Error t value
#(Intercept)      0.81422    0.06971  11.679
#q8fIMPLivestock -0.09455    0.06482  -1.459
confint(q8fIMPLivestock.mod, level = 0.85)
#q8fIMPLivestock -0.1884903 -0.0008701114


#_2c. Total Veg----
AICregress_mods(ponds.w.laow$TotalVeg,ponds.w.laow)

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#IncomeTotal      4 3025.676    0.0000 0.1506 0.1506 -1508.838
#IncomeAg         4 3026.236    0.5604 0.1138 0.2644 -1509.118
#Crops            4 3026.777    1.1011 0.0868 0.3512 -1509.389
#ManageSportFish  4 3027.108    1.4324 0.0736 0.4248 -1509.554
#Education        4 3027.366    1.6902 0.0647 0.4894 -1509.683
#Null             3 3028.044    2.3680 0.0461 0.5355 -1511.022


#q31IncomeTot
q31IncomeTot.mod=lmer(TotalVeg~q31IncomeTot+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q31IncomeTot.mod)
#             Estimate Std. Error t value
#(Intercept)   1.35275    0.05347  25.300
#q31IncomeTot -0.11011    0.05191  -2.121
confint(q31IncomeTot.mod,level = 0.85)
#q31IncomeTot -0.1856157 -0.03491003

#q8dIMPIncomeAgr
q8dIMPIncomeAgr.mod=lmer(TotalVeg~q8dIMPIncomeAgr+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8dIMPIncomeAgr.mod)
#                Estimate Std. Error t value
#(Intercept)      1.34823    0.05380  25.058
#q8dIMPIncomeAgr -0.09729    0.04920  -1.978
confint(q8dIMPIncomeAgr.mod,level = 0.85)
#q8dIMPIncomeAgr -0.1682651 -0.02588286

#q8jIMPCrops 
q8jIMPCrops.mod=lmer(TotalVeg~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q8jIMPCrops.mod)
#            Estimate Std. Error t value
#(Intercept)  1.35036    0.05337   25.30
#q8jIMPCrops -0.09548    0.05161   -1.85
confint(q8jIMPCrops.mod,level = 0.85)
#q8jIMPCrops -0.1700525 -0.01993774

#q12p2ManageSportFish
q12p2ManageSportFish.mod=lmer(TotalVeg~q12p2ManageSportFish+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q12p2ManageSportFish.mod)
#                     Estimate Std. Error t value
#(Intercept)           1.34663    0.05517  24.408
#q12p2ManageSportFish  0.09086    0.05294   1.716
confint(q12p2ManageSportFish.mod,level = 0.85)
#q12p2ManageSportFish 0.01459249 0.1687379

#q34Education      
q34Education.mod=lmer(TotalVeg~q34Education+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,REML="FALSE")
summary(q34Education.mod)
#             Estimate Std. Error t value
#(Intercept)   1.36094    0.05494  24.772
#q34Education -0.08611    0.05253  -1.639
confint(q34Education.mod,level = 0.85)
#q34Education -0.1631372 -0.01041438


#_2d. Floating Veg----
AICregress_mods(ponds.w.laow$Floating,ponds.w.laow)

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#Null             3 2756.933    0.0000 0.0748 0.0748 -1375.467
#ManageOtherFrogs 4 2757.243    0.3101 0.0640 0.1388 -1374.622
#Age              4 2757.314    0.3804 0.0618 0.2007 -1374.657
#PropertyValue    4 2757.760    0.8266 0.0495 0.2501 -1374.880

#_2e. Pond Renovation----

#Only ponds that are >= 40 YO (PondOriginYR >1990) are considered here

ponds.w.laow.40 <- ponds.w.laow %>%
  filter(PondOriginYR <= 1990)

#ponds.w.laow.30 <- ponds.w.laow %>%
#  filter(PondOriginYR <= 2000)

AICregress_modsBIN(ponds.w.laow.40$RebuiltYN,ponds.w.laow.40,binomial)

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#ManageBullfrogs  3 260.4347    0.0000 0.1389 0.1389 -127.2174
#Gender           3 261.1705    0.7358 0.0961 0.2350 -127.5853
#Crops            3 262.1953    1.7606 0.0576 0.2926 -128.0977
#Null             2 262.2851    1.8503 0.0551 0.3476 -129.1425

#q12n2ManageBullfrogs
q12n2ManageBullfrogs.mod=glmer(Fence~q12n2ManageBullfrogs+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q12n2ManageBullfrogs.mod)
#                     Estimate Std. Error z value Pr(>|z|)
#(Intercept)          -0.19220    0.16963  -1.133    0.257
#q12n2ManageBullfrogs -0.05243    0.16825  -0.312    0.755
confint(q12n2ManageBullfrogs.mod,level = 0.85)
#q12n2ManageBullfrogs -0.2997149 0.19472174

#q29Gender
q29Gender.mod=glmer(Fence~q29Gender+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q29Gender.mod)
#            Estimate Std. Error z value Pr(>|z|)
#(Intercept) -0.19320    0.16966  -1.139    0.255
#q29Gender    0.03147    0.15310   0.206    0.837
confint(q29Gender.mod,level = 0.85)
#q29Gender    -0.1983082 0.25157027

#q8jIMPCrops
q8jIMPCrops.mod=glmer(Fence~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q8jIMPCrops.mod)
#            Estimate Std. Error z value Pr(>|z|)  
#(Intercept)  -0.2283     0.1628  -1.402   0.1610  
#q8jIMPCrops  -0.2701     0.1604  -1.684   0.0921 .
confint(q8jIMPCrops.mod,level = 0.85)
#q8jIMPCrops -0.5040537 -0.033024149


#_2f. Cattle In (grazed)---- 
ponds.w.laowGRAZED<- ponds.w.laow %>%
  filter(GrazedLand ==1)

AICregress_modsBIN(ponds.w.laowGRAZED$CattleIN,ponds.w.laowGRAZED,binomial)

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#OtherFrogs       3 474.8614    0.0000 0.1031 0.1031 -234.4307
#Bullfrogs        3 475.3288    0.4675 0.0816 0.1846 -234.6644
#Age              3 475.5531    0.6917 0.0729 0.2576 -234.7766
#Null             2 475.9839    1.1225 0.0588 0.3164 -235.9919

q12oIMPOtherFrogs.mod = glmer(CattleIN~q12oIMPOtherFrogs+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZED,REML="FALSE")
summary(q12oIMPOtherFrogs.mod)
#Fixed effects:
#                   Estimate Std. Error z value Pr(>|z|)    
#(Intercept)         1.1779     0.2145   5.492 3.98e-08 ***
#q12oIMPOtherFrogs  -0.3465     0.1956  -1.771   0.0765 .  
confint(q12oIMPOtherFrogs.mod,level=0.85)
#                   7.5 %      92.5 %
#  .sig01           0.7928949  1.46807408
#(Intercept)        0.8853869  1.51263101
#q12oIMPOtherFrogs -0.6384031 -0.06546419

q12nIMPBullfrogs.mod = glmer(CattleIN~q12nIMPBullfrogs+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZED,REML="FALSE")
summary(q12nIMPBullfrogs.mod)
#                 Estimate Std. Error z value Pr(>|z|)    
#(Intercept)        1.1600     0.2125   5.458 4.83e-08 ***
#q12nIMPBullfrogs  -0.3149     0.1912  -1.647   0.0995 .  
confint(q12nIMPBullfrogs.mod,level=0.85)
#q12nIMPBullfrogs -0.5972217 -0.03767305

Age.mod = glmer(CattleIN~Age+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZED,REML="FALSE")
summary(Age.mod)
#           Estimate Std. Error z value Pr(>|z|)    
#(Intercept)   1.1694     0.2168   5.394  6.9e-08 ***
#  Age          -0.2991     0.1949  -1.534    0.125    
confint(Age.mod,level=0.85)
#Age         -0.5918949 -0.02293606


#_2g. Cattle Out (grazed and fenced)----
ponds.w.laowGRAZEDFENCED<- ponds.w.laow %>%
  filter((GrazedLand ==1) & (Fence == 1))

AICregress_modsBIN(ponds.w.laowGRAZEDFENCED$CattleOUT,ponds.w.laowGRAZEDFENCED,binomial)

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#Livestock        3 239.3889    0.0000 0.0924 0.0924 -116.6944
#Bullfrogs        3 239.7645    0.3756 0.0766 0.1691 -116.8822
#OtherFrogs       3 239.8350    0.4461 0.0740 0.2430 -116.9175
#Age              3 240.1209    0.7321 0.0641 0.3071 -117.0605
#LiveonLand       3 240.1229    0.7340 0.0640 0.3712 -117.0614
#Null             2 240.2806    0.8917 0.0592 0.4304 -118.1403

q8fIMPLivestock.mod = glmer(CattleOUT~q8fIMPLivestock+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED,REML="FALSE")
summary(q8fIMPLivestock.mod)
#                Estimate Std. Error z value Pr(>|z|)   
#(Intercept)       0.9128     0.3358   2.719  0.00656 **
#q8fIMPLivestock  -0.7790     0.4700  -1.657  0.09744 . 
confint(q8fIMPLivestock.mod,level=0.85)
#q8fIMPLivestock -1.4996761 -0.1196455

q12nIMPBullfrogs.mod= glmer(CattleOUT~q12nIMPBullfrogs+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED,REML="FALSE")
summary(q12nIMPBullfrogs.mod)
#                 Estimate Std. Error z value Pr(>|z|)  
#(Intercept)        0.5487     0.2355   2.330   0.0198 *
#q12nIMPBullfrogs   0.3772     0.2415   1.562   0.1183  
confint(q12nIMPBullfrogs.mod,level=0.85)
#q12nIMPBullfrogs 0.0350408 0.7526280


q12oIMPOtherFrogs.mod=glmer(CattleOUT~q12oIMPOtherFrogs+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED,REML="FALSE")
summary(q12oIMPOtherFrogs.mod)
#                  Estimate Std. Error z value Pr(>|z|)  
#(Intercept)         0.5294     0.2373   2.231   0.0257 *
#q12oIMPOtherFrogs   0.3781     0.2479   1.525   0.1272  
confint(q12oIMPOtherFrogs.mod,level=0.85)
#q12oIMPOtherFrogs 0.0299392 0.7684541

Age.mod=glmer(CattleOUT~Age+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED,REML="FALSE")
summary(Age.mod)
#            Estimate Std. Error z value Pr(>|z|)  
#(Intercept)   0.5415     0.2411   2.246   0.0247 *
#Age           0.3225     0.2267   1.423   0.1548  
confint(Age.mod,level=0.85)
#Age         0.006448248 0.6813990


q3LiveonLand.mod=glmer(CattleOUT~q3LiveonLand+(1|LaOw_ID),family = binomial,na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED,REML="FALSE")
summary(q3LiveonLand.mod)
#             Estimate Std. Error z value Pr(>|z|)  
#(Intercept)    0.6398     0.2544   2.515   0.0119 *
#q3LiveonLand   0.4689     0.3357   1.397   0.1624  
confint(q3LiveonLand.mod,level=0.85)
#q3LiveonLand 0.009052627 0.9957702


#_2h. Fencing----
ponds.w.laowFENCED <- ponds.w.laow %>%
  filter(!Fence ==2)
AICregress_modsBIN(ponds.w.laowFENCED$Fence,ponds.w.laowFENCED,binomial) #ponds regardless of grazed land

#                 K      AIC Delta_AIC AICWt Cum.Wt        LL
#Livestock        3 916.1507    0.0000     1      1 -455.0754
#WildlifeHabitat  3 943.2947   27.1439     0      1 -468.6473
#LiveonLand       3 948.9431   32.7923     0      1 -471.4715
#Ducks            3 949.7381   33.5873     0      1 -471.8690
#Recreation       3 950.0116   33.8609     0      1 -472.0058
#Crops            3 951.0382   34.8874     0      1 -472.5191
#IncomeAg         3 951.2319   35.0812     0      1 -472.6160
#PropIncomeLand   3 951.4835   35.3328     0      1 -472.7418
#Null             2 952.6721   36.5214     0      1 -474.3361

q8fIMPLivestock.mod=glmer(Fence~q8fIMPLivestock+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q8fIMPLivestock.mod)
#                Estimate Std. Error z value Pr(>|z|)    
#(Intercept)      -1.3627     0.1658  -8.218  < 2e-16 ***
#q8fIMPLivestock   0.9866     0.1816   5.433 5.54e-08 ***
confint(q8fIMPLivestock.mod, level = 0.85)
#q8fIMPLivestock  0.7397320  1.266488

q9cIMPWildlifeHabitat.mod=glmer(Fence~q9cIMPWildlifeHabitat+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q9cIMPWildlifeHabitat.mod)
#                      Estimate Std. Error z value Pr(>|z|)    
#(Intercept)            -1.4278     0.1789  -7.982 1.44e-15 ***
#q9cIMPWildlifeHabitat  -0.5152     0.1608  -3.205  0.00135 ** 
confint(q9cIMPWildlifeHabitat.mod, level = 0.85)
#q9cIMPWildlifeHabitat    -0.7592595 -0.2917381

q3LiveonLand.mod=glmer(Fence~q3LiveonLand+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q3LiveonLand.mod)
#             Estimate Std. Error z value Pr(>|z|)    
#(Intercept)   -1.4126     0.1779  -7.940 2.02e-15 ***
#q3LiveonLand  -0.3612     0.1551  -2.329   0.0199 *  
confint(q3LiveonLand.mod, level = 0.85)
#q3LiveonLand   -0.5932832 -0.1428921

q12mIMPDucks.mod=glmer(Fence~q12mIMPDucks+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q12mIMPDucks.mod)
#            Estimate Std. Error z value Pr(>|z|)    
#(Intercept)   -1.4192     0.1789  -7.931 2.17e-15 ***
#q12mIMPDucks  -0.3521     0.1622  -2.171   0.0299 *  
confint(q12mIMPDucks.mod, level = 0.85)
#q12mIMPDucks -0.5949176 -0.1233422

#Recreation    
q8iIMPRec.mod=glmer(Fence~q8iIMPRec+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q8iIMPRec.mod)
#            Estimate Std. Error z value Pr(>|z|)    
#(Intercept)  -1.4353     0.1806  -7.948  1.9e-15 ***
#q8iIMPRec    -0.3364     0.1601  -2.101   0.0357 *  
confint(q8iIMPRec.mod, level = 0.85)
#q8iIMPRec   -0.5765722 -0.1111233

#Crops
q8jIMPCrops.mod=glmer(Fence~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q8jIMPCrops.mod)
#           Estimate Std. Error z value Pr(>|z|)    
#(Intercept)  -1.4794     0.1780  -8.310   <2e-16 ***
#q8jIMPCrops  -0.2957     0.1522  -1.943    0.052 .  
confint(q8jIMPCrops.mod, level = 0.85)
#q8jIMPCrops -0.5172580 -0.07424945

#IncomeAg
q8dIMPIncomeAgr.mod=glmer(Fence~q8dIMPIncomeAgr+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q8dIMPIncomeAgr.mod)
#                 Estimate Std. Error z value Pr(>|z|)       
#(Intercept)      -1.4254     0.1810  -7.877 3.36e-15 ***
#q8dIMPIncomeAgr   0.2688     0.1496   1.797   0.0723 .  
confint(q8dIMPIncomeAgr.mod, level = 0.85)
#q8dIMPIncomeAgr       0.05923201  0.4937517

#PropIncomeLand
q32ProportionIncomeLand.mod=glmer(Fence~q32ProportionIncomeLand+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowFENCED,family = binomial)
summary(q32ProportionIncomeLand.mod)
#                        Estimate Std. Error z value Pr(>|z|)    
#(Intercept)              -1.3919     0.1848  -7.532    5e-14 ***
#q32ProportionIncomeLand   0.2939     0.1708   1.721   0.0853 .  
confint(q32ProportionIncomeLand.mod, level = 0.85)
#q32ProportionIncomeLand      0.05584664  0.5526886


#_2i. Fencing---- 
ponds.w.laowGRAZEDFENCED2 <- ponds.w.laowFENCED %>%
  filter(GrazedLand ==1)

AICregress_modsBIN(ponds.w.laowGRAZEDFENCED2$Fence,ponds.w.laowGRAZEDFENCED2,binomial) #ponds regardless of grazed land

#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#ManageSportFish  3 563.4480    0.0000 0.0903 0.0903 -278.7240
#Crops            3 563.6566    0.2086 0.0814 0.1717 -278.8283
#SportFish        3 564.0008    0.5528 0.0685 0.2402 -279.0004
#Null             2 564.3144    0.8665 0.0586 0.2988 -280.1572

#ManageSportFish
q12p2ManageSportFish.mod=glmer(Fence~q12p2ManageSportFish+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q12p2ManageSportFish.mod)
#                      Estimate Std. Error z value Pr(>|z|)  
#(Intercept)           -0.1834     0.1663  -1.103   0.2701  
#q12p2ManageSportFish   0.2849     0.1678   1.697   0.0896 .
confint(q12p2ManageSportFish.mod, level = 0.85)
#q12p2ManageSportFish      0.04340536 0.53607332

#Crops
q8jIMPCrops.mod=glmer(Fence~q8jIMPCrops+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q8jIMPCrops.mod)
#            Estimate Std. Error z value Pr(>|z|)  
#(Intercept)  -0.2283     0.1628  -1.402   0.1610  
#q8jIMPCrops  -0.2701     0.1604  -1.684   0.0921 .
confint(q8jIMPCrops.mod, level = 0.85)
#q8jIMPCrops        -0.5040537 -0.033024149


#SportFish
q12pIMPSportFish.mod=glmer(Fence~q12pIMPSportFish+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laowGRAZEDFENCED2,family = binomial)
summary(q12pIMPSportFish.mod)
#                 Estimate Std. Error z value Pr(>|z|)
#(Intercept)       -0.1661     0.1660  -1.000    0.317
#q12pIMPSportFish   0.2561     0.1669   1.534    0.125
confint(q12pIMPSportFish.mod, level = 0.85)
#q12pIMPSportFish       0.01407924 0.5052996


#_2j. Permanent----
AICregress_modsBIN(ponds.w.laow$Permanent,ponds.w.laow,binomial)
#                 K      AIC Delta_AIC  AICWt Cum.Wt        LL
#Ponds Owned      3 773.9576    0.0000 0.3425 0.3425 -383.9788
#Education        3 777.1246    3.1669 0.0703 0.4128 -385.5623
#Null             2 777.9043    3.9466 0.0476 0.4604 -386.9521

PondsOwned.mod=glmer(Permanent~PondsOwned+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,family = binomial)
summary(PondsOwned.mod)
#           Estimate Std. Error z value Pr(>|z|)    
#(Intercept)   1.7518     0.1167  15.011  < 2e-16 ***
#PondsOwned   -0.2889     0.1059  -2.728  0.00638 ** 
confint(PondsOwned.mod, level =0.85)
#PondsOwned     -0.4484257 -0.1275428

q34Education.mod=glmer(Permanent~q34Education+(1|LaOw_ID),na.action=na.exclude,data=ponds.w.laow,family = binomial)
summary(q34Education.mod)
#             Estimate Std. Error z value Pr(>|z|)    
#(Intercept)    1.8545     0.1347  13.772   <2e-16 ***
#q34Education   0.1916     0.1170   1.638    0.102    
confint(q34Education.mod, level =0.85)
#q34Education     0.0257474 0.3668612


#3. Figure 4. ----
setwd()

table <- read_csv("Data S2_Regression model coefficients and confidence intervals.csv")

table1 <- table %>%
  mutate(name=paste0(Response, "_", Predictor))


panel.plotfunct <- function(resp,data) {
  ggplot() +
    geom_linerange(data = subset(data, Response == resp), 
                   aes(x = reorder(Predictor,Estimate), ymin = LCI, ymax = UCI),
                   color = "darkgrey",
                   size = 3)+
    geom_point(data = subset(data, Response == resp),aes(x = reorder(Predictor,Estimate), y= Estimate),size = 1,na.rm = FALSE)+
              theme_pubr()+
                theme(legend.position = "right")+
                labs(
                  x = NULL,
                  y = NULL,
                  subtitle = resp
                )+
                theme(panel.grid.major.y = element_line(linetype = "dotted", 
                                                        color = "grey"))+
                geom_hline(yintercept=0)+
                scale_y_continuous(limits = c(-1.6,1.5),breaks= seq(-2,1.5,by = 0.5),labels = NULL)+
                coord_flip()
}
age.plot      <- panel.plotfunct("PondAge",table1)+
  scale_y_continuous(limits = c(-4.5,1.5),breaks= seq(-4.5,1.5,by = 1))+
  labs(subtitle = "(a) Pond Age")
cat.plot      <- panel.plotfunct("Cattails",table1)+
  labs(subtitle = "(b) Cattails")
tot.veg.plot  <- panel.plotfunct("TotalVeg",table1)+
  labs(subtitle = "(c) TotalVeg")
renov  <- panel.plotfunct("Renovated",table1)+
  labs(subtitle = "(d) Renovated")
g.cat.plot    <- panel.plotfunct("CattleIn_grazed",table1)+
  labs(subtitle = "(e) Cattle In (grazed ponds)")
gf.cat.plot   <- panel.plotfunct("CattleOut_grazedfenced",table1)+
  labs(subtitle = "(f) Cattle Out (grazed & fenced ponds)")
f.fence.plot  <- panel.plotfunct("Fenced",table1)+
  labs(subtitle = "(g) Fenced")
gf.fence.plot <- panel.plotfunct("Fenced_grazed",table1)+
  scale_y_continuous(limits = c(-1.6,1.5),breaks= seq(-2,1.5,by = 0.5))+
  labs(y = "Standardized regression coefficient")+
  labs(subtitle = "(h) Fenced (grazed ponds)")
perm.plot     <- panel.plotfunct("Permanent",table1)+
  scale_y_continuous(limits = c(-1.6,1.5),breaks= seq(-2,1.5,by = 0.5))+
  labs(y = "Standardized regression coefficient")+
  labs(subtitle = "(i) Permanent")

plot_grid(age.plot,
          cat.plot,
          tot.veg.plot,
          renov,
          g.cat.plot,
          gf.cat.plot,
          f.fence.plot,
          gf.fence.plot,
          perm.plot,
          nrow = 5, ncol = 2, align = "v")
